#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty


class ABQMechConnBehavior(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQMechConnBehavior
                | 
                | Represents an Abaqus mechanical connection behavior (ABQMechConnBehavior)
                | object.
                | Role: Access an Abaqus mechanical connection behaviour object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_mech_conn_behavior = com_object

    @property
    def allow_separation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AllowSeparation() As boolean
                | 
                |     Sets or returns the seperation status for the hard contact pressure
                |     overclosure.
                | 
                |     Returns:
                |         A boolean specifying whether seperation status is on or
                |         off.

        :rtype: bool
        """

        return self.abq_mech_conn_behavior.AllowSeparation

    @allow_separation.setter
    def allow_separation(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mech_conn_behavior.AllowSeparation = value

    @property
    def apply_user_subroutine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyUserSubroutine() As boolean
                | 
                |     Sets or returns the user subroutine flag.
                | 
                |     Returns:
                |         A boolean specifying whether a user subroutine will be applied.

        :rtype: bool
        """

        return self.abq_mech_conn_behavior.ApplyUserSubroutine

    @apply_user_subroutine.setter
    def apply_user_subroutine(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mech_conn_behavior.ApplyUserSubroutine = value

    @property
    def augmented_lagrange(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AugmentedLagrange() As boolean
                | 
                |     Sets or returns the augmented lagrange formulation in a mechanical
                |     connection.
                | 
                |     Returns:
                |         A boolean specifying whether augmented lagrange formulation is
                |         applied.

        :rtype: bool
        """

        return self.abq_mech_conn_behavior.AugmentedLagrange

    @augmented_lagrange.setter
    def augmented_lagrange(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mech_conn_behavior.AugmentedLagrange = value

    @property
    def clearance_contact_pressure_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ClearanceContactPressureValue() As double
                | 
                |     Sets or returns the clearance at which contact pressure is zero in a
                |     mechanical connection.
                | 
                |     Returns:
                |         clearance at which contact pressure is zero.

        :rtype: float
        """

        return self.abq_mech_conn_behavior.ClearanceContactPressureValue

    @clearance_contact_pressure_value.setter
    def clearance_contact_pressure_value(self, value: float):
        """
        :param float value:
        """

        self.abq_mech_conn_behavior.ClearanceContactPressureValue = value

    @property
    def contact_stiffness(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactStiffness() As ContactStiffness_Type
                | 
                |     Sets or returns the contact stiffness type hard contact pressure
                |     overclosure.
                | 
                |     Returns:
                |         The contact stiffness
                | 
                |         Legal values:
                | 
                |         DEFAULT
                |         STIFF_VALUE

        :rtype: int
        """

        return self.abq_mech_conn_behavior.ContactStiffness

    @contact_stiffness.setter
    def contact_stiffness(self, value: int):
        """
        :param int value:
        """

        self.abq_mech_conn_behavior.ContactStiffness = value

    @property
    def contact_stiffness_scale_factor_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactStiffnessScaleFactorValue() As double
                | 
                |     Sets or returns the contact stiffness scale factor value in a mechanical
                |     connection.
                | 
                |     Returns:
                |         contact stiffness scale factor value.

        :rtype: float
        """

        return self.abq_mech_conn_behavior.ContactStiffnessScaleFactorValue

    @contact_stiffness_scale_factor_value.setter
    def contact_stiffness_scale_factor_value(self, value: float):
        """
        :param float value:
        """

        self.abq_mech_conn_behavior.ContactStiffnessScaleFactorValue = value

    @property
    def contact_stiffness_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactStiffnessValue() As double
                | 
                |     Sets or returns the contact stiffness value for hard contact pressure
                |     overclosure.
                | 
                |     Returns:
                |         The stiffness value.

        :rtype: float
        """

        return self.abq_mech_conn_behavior.ContactStiffnessValue

    @contact_stiffness_value.setter
    def contact_stiffness_value(self, value: float):
        """
        :param float value:
        """

        self.abq_mech_conn_behavior.ContactStiffnessValue = value

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Sets or returns the description.
                | 
                |     Returns:
                |         The description of the step.

        :rtype: str
        """

        return self.abq_mech_conn_behavior.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_mech_conn_behavior.Description = value

    @property
    def formulation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Formulation() As Formulation_Type
                | 
                |     Sets or returns the formulation in a mechanical
                |     connection.
                | 
                |     Returns:
                |         The formulation.
                | 
                |         Legal values:
                | 
                |         FRICTIONLESS
                |         PENALTY

        :return: enum formulation_type
        :rtype: int
        """

        return self.abq_mech_conn_behavior.Formulation

    @formulation.setter
    def formulation(self, value: int):
        """
        :param int value: enum formulation_type
        """

        self.abq_mech_conn_behavior.Formulation = value

    @property
    def friction_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrictionCoefficient() As double
                | 
                |     Sets or returns the friction coefficient if the formulation is
                |     PENALTY.
                | 
                |     Returns:
                |         The friction coefficient.

        :rtype: float
        """

        return self.abq_mech_conn_behavior.FrictionCoefficient

    @friction_coefficient.setter
    def friction_coefficient(self, value: float):
        """
        :param float value:
        """

        self.abq_mech_conn_behavior.FrictionCoefficient = value

    @property
    def max_stiffness(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxStiffness() As MaxStiffness_Type
                | 
                |     Sets or returns the contact stiffness type hard contact pressure
                |     overclosure.
                | 
                |     Returns:
                |         The contact stiffness
                | 
                |         Legal values:
                | 
                |         DEFAULT
                |         STIFF_VALUE

        :return: enum max_stiffness_type
        :rtype: int
        """

        return self.abq_mech_conn_behavior.MaxStiffness

    @max_stiffness.setter
    def max_stiffness(self, value: int):
        """
        :param int value: enum max_stiffness_type
        """

        self.abq_mech_conn_behavior.MaxStiffness = value

    @property
    def max_stiffness_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxStiffnessValue() As double
                | 
                |     Sets or returns the max stiffness value for mechanical
                |     connection.
                | 
                |     Returns:
                |         The stiffness value.

        :rtype: float
        """

        return self.abq_mech_conn_behavior.MaxStiffnessValue

    @max_stiffness_value.setter
    def max_stiffness_value(self, value: float):
        """
        :param float value:
        """

        self.abq_mech_conn_behavior.MaxStiffnessValue = value

    @property
    def penalty_method(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PenaltyMethod() As boolean
                | 
                |     Sets or returns the penalty method formulation in a mechanical
                |     connection.
                | 
                |     Returns:
                |         A boolean specifying whether penalty method formulation is applied.

        :rtype: bool
        """

        return self.abq_mech_conn_behavior.PenaltyMethod

    @penalty_method.setter
    def penalty_method(self, value: bool):
        """
        :param bool value:
        """

        self.abq_mech_conn_behavior.PenaltyMethod = value

    @property
    def pressure_overclosure(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PressureOverclosure() As PressureOverclosure_Type
                | 
                |     Sets or returns the pressure overclosure in a mechanical
                |     connection.
                | 
                |     Returns:
                |         The pressure overclosure.
                | 
                |         Legal values:
                | 
                |         HARD
                |         EXPONENTIAL
                |         LINEAR
                |         TABULAR

        :return: enum pressure_overclosure_type
        :rtype: int
        """

        return self.abq_mech_conn_behavior.PressureOverclosure

    @pressure_overclosure.setter
    def pressure_overclosure(self, value: int):
        """
        :param int value: enum pressure_overclosure_type
        """

        self.abq_mech_conn_behavior.PressureOverclosure = value

    def add_pressure_overclosure_table(self, i_pressure: tuple, i_overclosure: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPressureOverclosureTable(CATSafeArrayVariant
                | iPressure,
                | CATSafeArrayVariant iOverclosure)
                | 
                |     Adds a list of tabular pressure overclosure in the connection behavior. The
                |     number of values in both of the parameters should match. If either list
                |     contains extra values, the extra values are discarded.
                | 
                |     Parameters:
                | 
                |         iPressure
                |             The list of pressure values.
                |         iOverclosure
                |             The list of overclosures.

        :param tuple i_pressure:
        :param tuple i_overclosure:
        :rtype: None
        """
        return self.abq_mech_conn_behavior.AddPressureOverclosureTable(i_pressure, i_overclosure)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_pressure_overclosure_table'
        # # vba_code = """
        # # Public Function add_pressure_overclosure_table(abq_mech_conn_behavior)
        # #     Dim iPressure (2)
        # #     abq_mech_conn_behavior.AddPressureOverclosureTable iPressure
        # #     add_pressure_overclosure_table = iPressure
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_pressure_overclosure_table(self, o_pressure: tuple, o_overclosure: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPressureOverclosureTable(CATSafeArrayVariant
                | oPressure,
                | CATSafeArrayVariant oOverclosure)
                | 
                |     Returns a list of tabular pressure overclosure in connection
                |     behavior.
                | 
                |     Parameters:
                | 
                |         oPressure
                |             The list of pressure values.
                |         oOverclosure
                |             The list of overclosures.

        :param tuple o_pressure:
        :param tuple o_overclosure:
        :rtype: None
        """
        return self.abq_mech_conn_behavior.GetPressureOverclosureTable(o_pressure, o_overclosure)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_pressure_overclosure_table'
        # # vba_code = """
        # # Public Function get_pressure_overclosure_table(abq_mech_conn_behavior)
        # #     Dim oPressure (2)
        # #     abq_mech_conn_behavior.GetPressureOverclosureTable oPressure
        # #     get_pressure_overclosure_table = oPressure
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQMechConnBehavior(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.item import Item
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class MfgAssemblyFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MfgAssemblyFactory
                | 
                | Represents the factory to creates a manufacturing assembly.
                | 
                | Role: It gives access to the C++ DNBIMfgAssemblyFactory interface methods Such
                | as
                | 
                |     Creates a manufacturing assembly
                | 
                | Example:
                |     This example fetches an instance of a Manufacturing Assembly factory in a a
                |     active document and then creates a manufactring assembly
                | 
                |      Dim objMAfact As MfgAssemblyFactory
                |      Set objMAfact =  CATIA.ActiveDocument.GetItem("MfgAssemblyFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mfg_assembly_factory = com_object

    def create_mfg_assembly(self, i_name_bstr: str, i_part_number_bstr: str, i_type: int) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateMfgAssembly(CATBSTR iNameBSTR,
                | CATBSTR iPartNumberBSTR,
                | DNBIAMfgAssemblyType iType) As Item
                | 
                |     Creates a manufacturing assembly of given type "iType". This API cannot be
                |     used to create a Manufacturing Assembly of type AST(assemblySpecTree) or
                |     Manufacturing Output(manufacturingOutput)
                | 
                |     Parameters:
                | 
                |         iNameBSTR
                |             Name of the manufacturing assembly 
                |         iPartNumberBSTR
                |             Part-number of the manufacturing assembly 
                |         iType
                |             Type of the Manufacturing Assembly. If its value is "notSpecified"
                |             (or 4), the new assembly created will be of type "manufacturingAssembly"
                |             
                |         oMfgAssembly
                |             Handler of the Manufacturing Assembly created
                | 
                |             Example:
                |                 This example creates a Manufacturing Assembly of type
                |                 "manufacturingKit" having MAName as "MKit1" and part-number as
                |                 "Kit1"
                | 
                |                  Dim matype As DNBIAMfgAssemblyType
                |                  matype=manufacturingKit
                |                  Dim MA As MfgAssembly (Or Dim MA As item)
                |                  objMAfact.CreateMfgAssembly
                |                  "MKit1","Kit1",matype,MA
                |                 where objMAfact is a instance of Automation Interface for
                |                 Manufacturing Assembly as shown earlier

        :param str i_name_bstr:
        :param str i_part_number_bstr:
        :param int i_type: enum dnbia_mfg_assembly_type
        :rtype: Item
        """
        return Item(self.mfg_assembly_factory.CreateMfgAssembly(i_name_bstr, i_part_number_bstr, i_type))

    def get_number_of_mfg_assemblies(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfMfgAssemblies() As long
                | 
                |     Get the number of Manufacturing Assemblies in MA Applicative
                |     Container
                | 
                |     Parameters:
                | 
                |         oNumOfMfgAssemblies
                |             number of Manufacturing Assemblies in MA Applicative
                |             Container
                | 
                |             Example:
                |                 For example getting the number of Manufacturing assemblies and
                |                 displaying them in the Message Box.
                | 
                |                  Dim nbMfgAssemblies 
                |                  Set nbMfgAssemblies =  objMAfact.GetNumberOfMfgAssemblies
                |                  MsgBox  nbMfgAssemblies

        :rtype: int
        """
        return self.mfg_assembly_factory.GetNumberOfMfgAssemblies()

    def get_number_of_all_mfg_assy(self, i_type: int, o_num_of_mfg_assemblies: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNumberofALLMfgAssy(DNBIAMfgAssemblyType iType,
                | long oNumOfMfgAssemblies)
                | 
                |     Get the number of Manufacturing Assemblies(MA) of given type in MA
                |     Applicative Container
                | 
                |     Parameters:
                | 
                |         iType
                |             Type of MA to be considered. If its value is "notSpecified" (or 4),
                |             all the MAs will be considered 
                |         oNumOfMfgAssemblies
                |             Number of MAs found
                | 
                |             Example:
                |                 For example getting the number of MA of type "manufacturingKit"
                |                 and displaying them in the Message Box.
                | 
                |                  Dim matype As DNBIAMfgAssemblyType
                |                  matype=manufacturingKit
                |                  Dim nbMfgAssemblies 
                |                  objMAfact.GetNumberofALLMfgAssy
                |                  matype,nbMfgAssemblies
                |                  MsgBox  nbMfgAssemblies

        :param int i_type: enum dnbia_mfg_assembly_type
        :param int o_num_of_mfg_assemblies:
        :rtype: None
        """
        return self.mfg_assembly_factory.GetNumberofALLMfgAssy(i_type, o_num_of_mfg_assemblies)

    def remove_mfg_assembly(self, i_mfg_assembly: Item) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveMfgAssembly(Item iMfgAssembly)
                | 
                |     Removes a given Manufacturing Assembly from the MA Applicative Container.
                |     Please note that the AST MA cannot be removed
                | 
                |     Parameters:
                | 
                |         iMfgAssembly
                |             Manufacturing assembly to be removed or deleted
                | 
                |             Example:
                |                 For example deleting the first MA from the Applicative
                |                 Container
                | 
                |                  Dim mfgAssy As Item
                |                  Set mfgAssy =  objMAfact.RetrieveMfgAssemblyAtIndex(1)
                |                  objMAfact.RemoveMfgAssembly mfgAssy

        :param Item i_mfg_assembly:
        :rtype: None
        """
        return self.mfg_assembly_factory.RemoveMfgAssembly(i_mfg_assembly.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_mfg_assembly'
        # # vba_code = """
        # # Public Function remove_mfg_assembly(mfg_assembly_factory)
        # #     Dim iMfgAssembly (2)
        # #     mfg_assembly_factory.RemoveMfgAssembly iMfgAssembly
        # #     remove_mfg_assembly = iMfgAssembly
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def retrieve_mfg_assembly(
            self,
            i_name_bstr: str,
            o_mfg_assemblies: tuple,
            o_num_of_mfg_assemblies: int
    ) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RetrieveMfgAssembly(CATBSTR iNameBSTR,
                | CATSafeArrayVariant oMfgAssemblies,
                | long oNumOfMfgAssemblies)
                | 
                |     Retrieve all the Manufacturing Assemblies of a given name.
                | 
                |     Parameters:
                | 
                |         iNameBSTR
                |             Name of the manufacturing assembly 
                |         oMfgAssemblies
                |             Array of the Items of the type "MfgAssembly". Array need to be
                |             allocated before passing. In case, if the size allocated is found to be less
                |             than the actual number of Manufacturing Assemblies found, the number of MAs
                |             returned will be equal to size of array passed only
                |             
                |         oNumOfMfgAssemblies
                |             Number of MAs found with the given name. If the actual number of
                |             MAs found is greater than the size of the array passed, then value returned
                |             will be equal to the size of the array itself.
                | 
                |             Example:
                |                 For example retriving all the MAs with the name "MA_TYPE1" from
                |                 the MA Applicative Container
                | 
                |                  Dim nbMfgAssemblies 
                |                  Set nbMfgAssemblies =  objMAfact.GetNumberOfMfgAssemblies
                |                  Dim MAList() As AnyObject
                |                  ReDim MAList(nbMfgAssemblies-1)
                |                  Dim NbMA 
                |                  objMAfact.RetrieveMfgAssembly
                |                  "MA_TYPE1",MAList,NbMA
                |                  MsgBox  NbMA

        :param str i_name_bstr:
        :param tuple o_mfg_assemblies:
        :param int o_num_of_mfg_assemblies:
        :rtype: AnyObject
        """
        return AnyObject(
            self.mfg_assembly_factory.RetrieveMfgAssembly(
                i_name_bstr,
                o_mfg_assemblies,
                o_num_of_mfg_assemblies
            )
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'retrieve_mfg_assembly'
        # # vba_code = """
        # # Public Function retrieve_mfg_assembly(mfg_assembly_factory)
        # #     Dim iNameBSTR (2)
        # #     mfg_assembly_factory.RetrieveMfgAssembly iNameBSTR
        # #     retrieve_mfg_assembly = iNameBSTR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def retrieve_mfg_assembly_at_index(self, i_index: cat_variant) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RetrieveMfgAssemblyAtIndex(CATVariant iIndex) As Item
                | 
                |     Retrieves a Manufacturing Assembly at the given index from the MA
                |     Applicative Container.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             Index 
                |         oItem
                |             Manufacturing Assembly at the above Index
                | 
                |             Example:
                |                 For example retriving all the MAs from the Applicative
                |                 Container
                | 
                |                  Dim nbMfgAssemblies 
                |                  Set nbMfgAssemblies =  objMAfact.GetNumberOfMfgAssemblies
                |                  For II = 0 to MyNum-1
                |                    Dim mfgAssy As Item
                |                     Set mfgAssy =  objMAfact.RetrieveMfgAssemblyAtIndex(II)
                |                 Next

        :param cat_variant i_index:
        :rtype: Item
        """
        return Item(self.mfg_assembly_factory.RetrieveMfgAssemblyAtIndex(i_index))

    def retrive_all_mfg_assy(self, i_type: int, o_all_m_as: tuple, o_num_of_mfg_assemblies: int) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RetriveALLMfgAssy(DNBIAMfgAssemblyType iType,
                | CATSafeArrayVariant oAllMAs,
                | long oNumOfMfgAssemblies)
                | 
                |     Retrieve all the Manufacturing Assemblies of a given type.
                | 
                |     Parameters:
                | 
                |         iType
                |             Type of manufacturing assemblies to be retrieved. If its value is
                |             "notSpecified" (or 4), all the manufacturing assemblies will be returned
                |             
                |         oMfgAssemblies
                |             Array of the Items of the type "MfgAssembly". Array need to be
                |             allocated before passing. In case, if the size allocated is found to be less
                |             than the actual number of Manufacturing Assemblies found, the number of MAs
                |             returned will be equal to size of array passed only
                |             
                |         oNumOfMfgAssemblies
                |             Number of MAs found. If the actual number of MAs found is greater
                |             than the size of the array passed, then value returned will be equal to the
                |             size of the array itself.
                | 
                |             Example:
                |                 For example: Code for retriving all the MAs of type
                |                 "manufacturingKit" from the MA Applicative
                |                 Container
                | 
                |                  Dim matype As DNBIAMfgAssemblyType
                |                  matype=manufacturingKit
                |                  Dim nbMfgAssemblies 
                |                  objMAfact.GetNumberofALLMfgAssy
                |                  matype,nbMfgAssemblies
                |                  Dim MAList() As AnyObject
                |                  ReDim MAList(nbMfgAssemblies)
                |                  Dim NbMA
                |                  objMAfact.RetriveALLMfgAssy
                |                  matype,MAList,NbMA

        :param int i_type: enum dnbia_mfg_assembly_type
        :param tuple o_all_m_as:
        :param int o_num_of_mfg_assemblies:
        :rtype: AnyObject
        """
        return AnyObject(self.mfg_assembly_factory.RetriveALLMfgAssy(i_type, o_all_m_as, o_num_of_mfg_assemblies))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'retrive_all_mfg_assy'
        # # vba_code = """
        # # Public Function retrive_all_mfg_assy(mfg_assembly_factory)
        # #     Dim iType (2)
        # #     mfg_assembly_factory.RetriveALLMfgAssy iType
        # #     retrive_all_mfg_assy = iType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MfgAssemblyFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator
from typing import TYPE_CHECKING

from pycatia.drafting_interfaces.drawing_component import DrawingComponent
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.drafting_interfaces.drawing_view import DrawingView


class DrawingComponents(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingComponents
                | 
                | A collection of all the drawing components (ditto) currently managed by a
                | drawing view of drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingComponent)
        self.drawing_components = com_object

    def add(self, i_drawing_component_ref: 'DrawingView', i_position_x: float, i_position_y: float) -> DrawingComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(DrawingView iDrawingComponentRef,
                | double iPositionX,
                | double iPositionY) As DrawingComponent
                | 
                |     Creates a drawing component instance and adds it to the DrawingComponents
                |     collection.
                | 
                |     Parameters:
                | 
                |         iDrawingComponentRef
                |             The view (i.e. the detail) that is the component reference . This
                |             view also called a detail MUST belong to a sheet of component references (i.e.
                |             details) 
                |         iPositionX,iPositionY
                |             The drawing component x and y coordinates, expressed in
                |             millimeters, with respect to the drawing view coordinate system
                |             
                | 
                |     Returns:
                |         The created drawing component instance 
                | 
                | Example:
                |     The following example creates a drawing component instance with a given
                |     component reference MyComponentRef coming from a Sheet of component references
                |     (i.e. details) SheetComponentRef and retrieved in MyComponentInst in the
                |     drawing view collection of the MyView drawing view. This view belongs to the
                |     drawing view collection of the drawing sheet
                | 
                |      Dim MyComponentRef As DrawingView
                |      Set MyComponentRef = SheetComponentRef.Views.Item(1)
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim MyComponentInst As DrawingComponent
                |      Set MyComponentInst = MyView.Components.Add(MyComponentRef, 100., 50.)

        :param DrawingView i_drawing_component_ref:
        :param float i_position_x:
        :param float i_position_y:
        :rtype: DrawingComponent
        """
        return DrawingComponent(
            self.drawing_components.Add(
                i_drawing_component_ref.com_object,
                i_position_x,
                i_position_y
            )
        )

    def item(self, i_index: cat_variant) -> DrawingComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As DrawingComponent
                | 
                |     Returns a drawing component instance using its index or its name from the
                |     DrawingComponents collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing component instance to retrieve
                |             from the collection of drawing components. As a numerics, this index is the
                |             rank of the drawing component instance in the collection. The index of the
                |             first drawing component instance in the collection is 1, and the index of the
                |             last drawing component instance is Count. As a string, it is the name you
                |             assigned to the drawing component instance using the
                |             
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved drawing component instance 
                | 
                | Example:
                |     This example retrieves in ThisDrawingComponent the second drawing component
                |     instance, MyView in the drawing view collection of the active sheet in the
                |     active document, supposed to be a drawing document.
                | 
                |      Dim MySheet As DrawingSheet
                |      Set MySheet = CATIA.ActiveDocument.Sheets.ActiveSheet
                |      Dim MyView  As DrawingView
                |      Set MyView  = MySheet.Views.ActiveView
                |      Dim ThisDrawingComponent As DrawingComponent
                |      Set ThisDrawingComponent = MyView.Components.Item(2)

        :param cat_variant i_index:
        :rtype: DrawingComponent
        """
        return DrawingComponent(self.drawing_components.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a drawing component from the DrawingComponents
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing component to remove from the collection of
                |             drawing components. As a numerics, this index is the rank of the drawing
                |             component in the collection. The index of the first drawing component instance
                |             in the collection is 1, and the index of the last drawing component instance is
                |             Count. As a string, it is the name you assigned to the drawing component using
                |             the 
                | 
                |         AnyObject.Name property 
                | 
                | Example:
                |     The following example removes the third drawing component instance in the
                |     drawing component collection of the active view of the active document,
                |     supposed to be a drawing document.
                | 
                |      Dim MyView As DrawingView
                |      Set MyView  = MySheet.Views.ActiveView
                |      MyView.Components.Remove(3)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.drawing_components.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingComponent:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingComponent(self.drawing_components.Item(n + 1))

    def __iter__(self) -> Iterator[DrawingComponent]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'DrawingComponents()'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPCntrFlow(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspCntrFlow
                | 
                | Represents Interface to manage Connector Flow property.
                | Role: To query and modify Plant-Ship Connector Flow property.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_cntr_flow = com_object

    @property
    def flow_capability(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlowCapability() As CatPspIDLFlowCapability
                | 
                |     Returns or sets Flow capability of the connector.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspCntrFlow
                |          Dim ojArg1 As CatPspIDLFlowCapability
                |           ...
                |          Set ojArg1 = objThisIntf.FlowCapability

        :return: enum cat_psp_idl_flow_capability
        :rtype: int
        """

        return self.psp_cntr_flow.FlowCapability

    @flow_capability.setter
    def flow_capability(self, value: int):
        """
        :param int value:
        """

        self.psp_cntr_flow.FlowCapability = value

    @property
    def flow_reality(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlowReality() As CatPspIDLFlowReality
                | 
                |     Returns or sets Flow reality of the connector.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspCntrFlow
                |          Dim ojArg1 As CatPspIDLFlowReality
                |           ...
                |          Set ojArg1 = objThisIntf.FlowReality

        :return: enum cat_psp_idl_flow_reality
        :rtype: int
        """

        return self.psp_cntr_flow.FlowReality

    @flow_reality.setter
    def flow_reality(self, value: int):
        """
        :param int value: enum cat_psp_idl_flow_reality
        """

        self.psp_cntr_flow.FlowReality = value

    def __repr__(self):
        return f'PSPCntrFlow(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_job import ABQJob
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQJobs(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQJobs
                | 
                | The collection of Abaqus (ABQJob) objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQJob)
        self.abq_jobs = com_object

    def add(self) -> ABQJob:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As ABQJob
                | 
                |     Creates a new Abaqus job and adds it to the collection of Abaqus
                |     jobs.
                | 
                |     Returns:
                |         oJob The Abaqus job object that was created. 
                |     Example:
                |         The following example creates a job in the ABQJobs
                |         collection:
                | 
                |          Dim abaqusJobs As ABQJobs
                |          Dim abqJob As ABQJob
                |          Set abaqusJobs = abqCase.Jobs
                |          Set abqJob =  abaqusJobs.Add()

        :rtype: ABQJob
        """
        return ABQJob(self.abq_jobs.Add())

    def item(self, i_index: cat_variant) -> ABQJob:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQJob
                | 
                |     Returns an Abaqus job using its index or its name from the ABQJobs
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus job to retrieve from the
                |             collection of Abaqus jobs. If the index is a number, it specifies the rank of
                |             the Abaqus job in the collection. The index of the first Abaqus job in the
                |             collection is 1, and the index of the last job is Count. If the index is a
                |             string, it specifies the name you assigned to the job using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         oJob The specified ABQJob.

        :param cat_variant i_index:
        :rtype: ABQJob
        """
        return ABQJob(self.abq_jobs.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus Job using its index or its name from the job
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the job to retrieve from the collection of
                |             jobs. As a numeric, this index is the rank of the job in the collection. The
                |             index of the first job in the collection is 1, and the index of the last job is
                |             Count. As a string, it is the name you assigned to the job using the
                |             CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_jobs.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_jobs)
        # #     Dim iIndex (2)
        # #     abq_jobs.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQJobs(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchComponent2(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchComponent2
                | 
                | Manage a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_component2 = com_object

    def place_in_space(
            self,
            i_grr: SchGRRComp,
            i_db6_axis: tuple,
            i_doc: Document,
            o_new_component: SchComponent
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PlaceInSpace(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb6Axis,
                | Document iDoc,
                | SchComponent oNewComponent)
                | 
                |     Place a component in space, unconnected to other objects. It will create
                |     local reference (from a catalog referenced document) if
                |     necessary.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         iDb6Axis[6]
                |             X-axis of the local axis of the new instance Y-axis of the local
                |             axis of the new instance X-Y coordinates of the orgin of the new instance. This
                |             axis defines the orientation and location of the new instance in space.
                |             
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent2
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(6) As CATSafeArrayVariant
                |          Dim objArg3 As Document
                |          Dim objArg4 As SchComponent
                |           ...
                |         
                |         objThisIntf.PlaceInSpaceobjArg1,dbVar2,objArg3,objArg4

        :param SchGRRComp i_grr:
        :param tuple i_db6_axis:
        :param Document i_doc:
        :param SchComponent o_new_component:
        :rtype: tuple
        """
        return self.sch_component2.PlaceInSpace(
            i_grr.com_object,
            i_db6_axis,
            i_doc.com_object,
            o_new_component.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'place_in_space'
        # # vba_code = """
        # # Public Function place_in_space(sch_component2)
        # #     Dim iGRR (2)
        # #     sch_component2.PlaceInSpace iGRR
        # #     place_in_space = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def place_on_object(
            self,
            i_grr: SchGRRComp,
            i_db6_axis: tuple,
            i_object_to_connect: SchAppConnectable,
            i_doc: Document,
            o_new_component: SchComponent
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PlaceOnObject(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb6Axis,
                | SchAppConnectable iObjectToConnect,
                | Document iDoc,
                | SchComponent oNewComponent)
                | 
                |     Place a component connected to another component or insert into a
                |     route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         iDb6Axis[6]
                |             X-axis of the local axis of the new instance Y-axis of the local
                |             axis of the new instance X-Y coordinates of the orgin of the new instance. This
                |             axis defines the orientation and location of the new instance in space.
                |             
                |         iObjectToConnect
                |             Pointer to a component to connect the new instance to or a route
                |             object to insert new component into. 
                |         iDoc
                |             Pointer to a document to create the object in. If NULL, the
                |             document associated with the current Editor will be used.
                |             
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent2
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(6) As CATSafeArrayVariant
                |          Dim objArg3 As SchAppConnectable
                |          Dim objArg4 As Document
                |          Dim objArg5 As SchComponent
                |           ...
                |          objThisIntf.PlaceOnObjectobjArg1,dbVar2,objArg3,objArg4,objArg5

        :param SchGRRComp i_grr:
        :param tuple i_db6_axis:
        :param SchAppConnectable i_object_to_connect:
        :param Document i_doc:
        :param SchComponent o_new_component:
        :rtype: tuple
        """
        return self.sch_component2.PlaceOnObject(
            i_grr.com_object,
            i_db6_axis,
            i_object_to_connect.com_object,
            i_doc.com_object,
            o_new_component.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'place_on_object'
        # # vba_code = """
        # # Public Function place_on_object(sch_component2)
        # #     Dim iGRR (2)
        # #     sch_component2.PlaceOnObject iGRR
        # #     place_on_object = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchComponent2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ArrangementItemReservation(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementItemReservation
                | 
                | Use this object to access the ArrangementItemReservation properties and
                | methods.
                | Role: Use this object to control the visualization mode, dimensions of the
                | ArrangementItemReservation.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_item_reservation = com_object

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Height() As double
                | 
                |     Returns or sets the height of the
                |     ArrangementItemReservation.
                | 
                |     Example:
                |         This example retrieves the Height of the objItemRes1
                |         object.
                | 
                |          Dim dblHeight   As Double
                |          dblHeight  = objItemRes1.Height

        :rtype: float
        """

        return self.arrangement_item_reservation.Height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.arrangement_item_reservation.Height = value

    @property
    def visu_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuMode() As CATArrangementItemResVisuMode
                | 
                |     Returns or set the Visualization Mode for the
                |     ArrangementItemReservation.
                | 
                |     Example:
                |         This example Sets the Visualization Mode of the objItemRes1 object to
                |         CatArrangementItemReservationVisuModeBox .
                | 
                |          objItemRes1.VisuMode = CatArrangementItemReservationVisuModeBox

        :return: enum cat_arrangement_item_res_visu_mode
        :rtype: int
        """

        return self.arrangement_item_reservation.VisuMode

    @visu_mode.setter
    def visu_mode(self, value: int):
        """
        :param int value: enum cat_arrangement_item_res_visu_mode
        """

        self.arrangement_item_reservation.VisuMode = value

    @property
    def x_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property XLength() As double
                | 
                |     Returns or sets the XLength of the
                |     ArrangementItemReservation.
                | 
                |     Example:
                |         This example retrieves the XLength of the objItemRes1
                |         object.
                | 
                |          Dim dblXLength   As Double
                |          dblXLength  = objItemRes1.XLength

        :rtype: float
        """

        return self.arrangement_item_reservation.XLength

    @x_length.setter
    def x_length(self, value: float):
        """
        :param float value:
        """

        self.arrangement_item_reservation.XLength = value

    @property
    def y_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property YLength() As double
                | 
                |     Returns or sets the YLength of the
                |     ArrangementItemReservation.
                | 
                |     Example:
                |         This example retrieves the YLength of the objItemRes1
                |         object.
                | 
                |          Dim dblYLength   As Double
                |          dblYLength  = objItemRes1.YLength

        :rtype: float
        """

        return self.arrangement_item_reservation.YLength

    @y_length.setter
    def y_length(self, value: float):
        """
        :param float value:
        """

        self.arrangement_item_reservation.YLength = value

    def get_dimension(self, io_item_res_dimensions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDimension(CATSafeArrayVariant ioItemResDimensions)
                | 
                |     Returns the Dimensions of the ArrangementItemReservation.
                | 
                |     Parameters:
                | 
                |         ioItemResDimensions
                |             The output array initialized with the dimensions that make up the
                |             ArrangementItemReservation. The first three components represent the Minimum
                |             XCoord, YCoord and Z Coord while the remaining three components represent the
                |             Maximum XCoord, YCoord and Z Coord respectively.
                | 
                |             Example:
                |                 This example retrieves the coordinate dimensions of the
                |                 objItemRes1 object.
                | 
                |                  Dim dblDimension(6)   As Double
                |                  objItemRes1.GetDimension(dblDimension)

        :param tuple io_item_res_dimensions:
        :rtype: None
        """
        return self.arrangement_item_reservation.GetDimension(io_item_res_dimensions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_dimension'
        # # vba_code = """
        # # Public Function get_dimension(arrangement_item_reservation)
        # #     Dim ioItemResDimensions (2)
        # #     arrangement_item_reservation.GetDimension ioItemResDimensions
        # #     get_dimension = ioItemResDimensions
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the applicative data whose type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                |         oApplicativeObj
                |             The matched applicative object.
                | 
                |             Example:
                |                 This example retrieves the desired applicative object from the
                |                 objItemRes1 object.
                | 
                |                  Dim objProd   As Product
                |                  objProd  = objItemRes1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_item_reservation.GetTechnologicalObject(i_application_type)

    def set_dimension(self, i_item_res_dimensions: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDimension(CATSafeArrayVariant iItemResDimensions)
                | 
                |     Sets the Dimensions of the ArrangementItemReservation.
                | 
                |     Parameters:
                | 
                |         iItemResDimensions
                |             The input array initialized with the dimensions that make up the
                |             ArrangementItemReservation. The first three components represent the Minimum
                |             XCoord, YCoord and Z Coord while the remaining three components represent the
                |             Maximum XCoord, YCoord and Z Coord respectively.
                | 
                |             Example:
                |                 This example sets the coordinate dimensions of the objItemRes1
                |                 object.
                | 
                |                  Dim dblDimension(6)   As Double
                |                  dblDimension(0)       = 300.0 '//XMin
                |                  dblDimension(1)       = 500.0 '//YMin
                |                  dblDimension(2)       = 300.0 '//ZMin
                |                  dblDimension(3)       = 500.0 '//XMax
                |                  dblDimension(4)       = 0.0   '//YMax
                |                  dblDimension(5)       = 300.0 '//ZMax
                |                  objItemRes1.SetDimension(dblDimension)

        :param tuple i_item_res_dimensions:
        :rtype: None
        """
        return self.arrangement_item_reservation.SetDimension(i_item_res_dimensions)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dimension'
        # # vba_code = """
        # # Public Function set_dimension(arrangement_item_reservation)
        # #     Dim iItemResDimensions (2)
        # #     arrangement_item_reservation.SetDimension iItemResDimensions
        # #     set_dimension = iItemResDimensions
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementItemReservation(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_machinable_area import ManufacturingMachinableArea
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingPrismaticMachiningArea(ManufacturingMachinableArea):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                        ManufacturingInterfaces.ManufacturingMachinableFeature
                |                            ManufacturingInterfaces.ManufacturingMachinableArea
                |                                ManufacturingPrismaticMachiningArea
                | 
                | ManufacturingPrismaticMachiningArea defines a set of properties and
                | methods.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_prismatic_machining_area = com_object

    @property
    def bottom_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BottomType() As CATBSTR
                | 
                |     Returns or sets the Hardness Mode on Bottom of a Manufacturing Prismatic
                |     Machining Area.
                | 
                |     Examples:
                |         The following example returns the hardness mode on bottom
                |         ThisBottomType of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim ThisBottomType As CATBSTR
                |          ThisBottomType = CurrentPMA.BottomType
                |
                |         The next example sets the hardness mode on bottom of the manufacturing
                |         prismatic machining area CurrentPMA
                | 
                |          CurrentPMA.BottomType = "MfgHard"
                |          
                |         To be allowed to change BottomType into MfgSoft, Islands geometries
                |         must be removed first.
                |          
                | 
                |     Legal values: BottomType can be
                | 
                |     MfgHard
                |     MfgSoft

        :rtype: str
        """

        return self.manufacturing_prismatic_machining_area.BottomType

    @bottom_type.setter
    def bottom_type(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_prismatic_machining_area.BottomType = value

    @property
    def contours_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContoursCount() As long (Read Only)
                | 
                |     Retreives the number of Contour of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Example:
                |         The following example returns the number of Contour NumberOfContour of
                |         the manufacturing prismatic machining area CurrentPMA
                | 
                |          Dim NumberOfContour As Long
                |          NumberOfContour = CurrentPMA.ContoursCount

        :rtype: int
        """

        return self.manufacturing_prismatic_machining_area.ContoursCount

    @property
    def islands_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IslandsCount() As long (Read Only)
                | 
                |     Retreives the number of Island of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Example:
                |         The following example returns the number of Island NumberOfIsland of
                |         the manufacturing prismatic machining area CurrentPMA
                | 
                |          Dim NumberOfIsland As Long
                |          NumberOfIsland = CurrentPMA.IslandsCount

        :rtype: int
        """

        return self.manufacturing_prismatic_machining_area.IslandsCount

    @property
    def top_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TopType() As CATBSTR
                | 
                |     Returns or sets the Hardness Mode on top of a Manufacturing Prismatic
                |     Machining Area.
                | 
                |     Examples:
                |         The following example returns the hardness mode on top ThisTopType of
                |         the manufacturing prismatic machining area CurrentPMA
                | 
                |          Dim ThisTopType As CATBSTR
                |          ThisTopType = CurrentPMA.TopType
                |
                |         The next example sets the hardness mode on top of the manufacturing
                |         prismatic machining area CurrentPMA
                | 
                |          CurrentPMA.TopType = "MfgHard"
                |
                |     Legal values: TopType can be
                | 
                |     MfgHard
                |     MfgSoft

        :rtype: str
        """

        return self.manufacturing_prismatic_machining_area.TopType

    @top_type.setter
    def top_type(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_prismatic_machining_area.TopType = value

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR
                | 
                |     Returns or sets the Type of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Examples:
                |         The following example returns the feature type ThisType of the
                |         manufacturing prismatic machining area CurrentPMA
                | 
                |          Dim ThisType As CATBSTR
                |          ThisType = CurrentPMA.Type
                |          
                |         The next example sets the feature type of the manufacturing prismatic
                |         machining area CurrentPMA
                | 
                |          CurrentPMA.Type = "MfgPocketType"
                |          
                |         To be allowed to change Type into MfgPocketType or into
                |         MfgContouringType, Contours and Islands geometries must be removed
                |         first.
                |
                |     Legal values: Type can be
                | 
                |     MfgPocketType
                |     MfgContouringType

        :rtype: str
        """

        return self.manufacturing_prismatic_machining_area.Type

    @type.setter
    def type(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_prismatic_machining_area.Type = value

    def get_contour_side(self, i_contour_number: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetContourSide(long iContourNumber) As short
                | 
                |     Gets the side of one contour of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iContourNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be between 1 and ContoursCount (see Properties).
                |
                |         Example: The following example gets the side of the contour number
                |         iContourNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iContourNumber As Long
                |          iContourNumber = 3
                | 
                |          Dim oContourSide As short
                |          oContourSide = CurrentPMA.GetContourSide(iContourNumber)

        :param int i_contour_number:
        :rtype: int
        """
        return self.manufacturing_prismatic_machining_area.GetContourSide(i_contour_number)

    def get_geometries_aquisition_mode(self, i_geometry_type: str, i_geometry_number: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGeometriesAquisitionMode(CATBSTR iGeometryType,
                | long iGeometryNumber) As short
                | 
                |     Gets the aquisition mode of one geometry of a Manufacturing Prismatic
                |     Machining Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             Contours
                |                 to get the aquisition mode of a guiding element
                |                 
                |             Islands
                |                 to get the aquisition mode of an island
                |                 (not allowed if Type == "MfgContouringType" or
                |                 if BottomType == "MfgSoft") (see Properties). 
                | 
                |         iGeometryNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be 1 if Type == "MfgPocketType" (see Properties) and
                |                 iGeometryType == "Contours". 
                |                 Must be between 1 and IslandsCount + 1 (or ContoursCount + 1)
                |                 (see Properties). 
                |
                |         Example: The following example gets the aquisition mode of the contour
                |         number iGeometryNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iGeometryNumber As Long
                |          iGeometryNumber = 3
                | 
                |          Dim oMode As Short
                |          oMode = CurrentPMA.GetGeometriesAquisitionMode("Contours",iGeometryNumber)
                |
                |         Legal values: GetGeometriesAquisitionMode value can be
                | 
                |         0
                |             by Edges 
                |         1
                |             by Belt of Faces 
                |         2
                |             by Boundary of Faces (Islands only) 
                |         5
                |             by Boundary of Faces (Contours only)

        :param str i_geometry_type:
        :param int i_geometry_number:
        :rtype: int
        """
        return self.manufacturing_prismatic_machining_area.GetGeometriesAquisitionMode(
            i_geometry_type,
            i_geometry_number
        )

    def is_contour_closed(self, i_contour_number: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsContourClosed(long iContourNumber) As short
                | 
                |     Return the status of one contour of a Manufacturing Prismatic Machining Area : closed or open.
                | 
                |     Parameters:
                | 
                |         iContourNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be between 1 and ContoursCount (see Properties).
                |
                |         Example: The following example returns the status of the contour number
                |         iContourNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iContourNumber As Long
                |          iContourNumber = 3
                | 
                |          Dim oIsClosed As short
                |          oIsClosed = CurrentPMA.IsContourClosed(iContourNumber)
                |
                |         Legal values: IsContourClosed value can be
                | 
                |         0 (means open contour)
                |         1 (means closed contour)

        :param int i_contour_number:
        :rtype: int
        """
        return self.manufacturing_prismatic_machining_area.IsContourClosed(i_contour_number)

    def remove_all_geometry(self, i_geometry_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAllGeometry(CATBSTR iGeometryType)
                | 
                |     Removes all the geometry of a specified type linked to a Manufacturing
                |     Prismatic Machining Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             RelimitingPlane
                |                 to remove the top plane 
                |             Parts
                |                 to remove the bottom 
                |             Checks
                |                 to remove the check elements 
                |             Contours
                |                 to remove the guiding elements 
                |             Islands
                |                 to remove the islands 
                |
                |         Example: The following example removes the bottom of the manufacturing
                |         prismatic machining area CurrentPMA
                | 
                |          Call CurrentPMA.RemoveAllGeometry("Parts")

        :param str i_geometry_type:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.RemoveAllGeometry(i_geometry_type)

    def set_closed_contour_side(self, i_contour_number: int, i_side: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetClosedContourSide(long iContourNumber,
                | CATBSTR iSide)
                | 
                |     Sets the side of one closed contour of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iContourNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be between 1 and ContoursCount (see Properties).
                |
                |         iSide
                |             Legal values: iSide can be
                | 
                |             Inside
                |             Outside
                |
                |         Example: The following example sets the side of the closed contour
                |         number iContourNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iContourNumber As Long
                |          iContourNumber = 3
                | 
                |          Dim iContourSide As CATBSTR
                |          iContourSide = "Inside"
                |          Call CurrentPMA.SetClosedContourSide(iContourNumber,iContourSide)

        :param int i_contour_number:
        :param str i_side:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.SetClosedContourSide(i_contour_number, i_side)

    def set_contour_side(self, i_contour_number: int, i_side: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetContourSide(long iContourNumber,
                | short iSide)
                | 
                |     Sets the side of one contour of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iContourNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be between 1 and ContoursCount (see Properties).
                |
                |         iSide
                |             Legal values: iSide can be
                | 
                |             1
                |             2
                |
                |         Example: The following example sets the side of the contour number
                |         iContourNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iContourNumber As Long
                |          iContourNumber = 3
                | 
                |          Dim iContourSide As Short
                |          iContourSide = 2
                |          Call CurrentPMA.SetContourSide(iContourNumber,iContourSide)

        :param int i_contour_number:
        :param int i_side:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.SetContourSide(i_contour_number, i_side)

    def set_geometries(
            self,
            i_geometry_type: str,
            i_mode: int,
            i_geometry_number: int,
            i_reference: AnyObject,
            i_product: AnyObject,
            i_position: int
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGeometries(CATBSTR iGeometryType,
                | short iMode,
                | long iGeometryNumber,
                | AnyObject iReference,
                | AnyObject iProduct,
                | short iPosition)
                | 
                |     Sets or adds geometry in a collection of a specified type to a
                |     Manufacturing Prismatic Machining Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             Contours
                |                 to set or to add a guiding element 
                |             Islands
                |                 to set or to add an island
                |                 (not allowed if Type == "MfgContouringType" or
                |                 if BottomType == "MfgSoft") (see Properties). 
                | 
                |         iMode
                |             Legal values: iMode can be
                | 
                |             0
                |                 by Edges 
                | 
                |         iGeometryNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be 1 if Type == "MfgPocketType" (see Properties) and
                |                 iGeometryType == "Contours". 
                |                 Must be between 1 and IslandsCount + 1 (or ContoursCount + 1)
                |                 (see Properties). 
                | 
                |         iReference
                |             The geometry to be set. 
                |         iProduct
                |             The product containing the geometry to be set. 
                |         iPosition
                |             0 
                |
                |         Example: The following example sets 3 Islands, linked to 2 circles and
                |         3 lines, to the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iGeometryNumber As Long
                |          iGeometryNumber = 0
                |          ...
                |          'Get number of Island of CurrentPMA and add 1 to create a new island
                |          (Island number 1)
                |          iGeometryNumber = CurrentPMA.IslandsCount + 1
                |          Call CurrentPMA.SetGeometries("Islands",0,iGeometryNumber,Circle1,PartMachined,0)
                |
                |          'Get number of Island of CurrentPMA and add 1 to create a new island 
                |          (Island number 2)
                |          iGeometryNumber = CurrentPMA.IslandsCount + 1
                |          Call CurrentPMA.SetGeometries("Islands",0,iGeometryNumber,Circle2,PartMachined,0)
                |
                |          'Get number of Island of CurrentPMA and add 1 to create a new island 
                |          (Island number 3)
                |          iGeometryNumber = CurrentPMA.IslandsCount + 1
                |          Call CurrentPMA.SetGeometries("Islands",0,iGeometryNumber,Line5,PartMachined,0)
                |
                |          'Adding Line6 to Island number 3
                |          Call CurrentPMA.SetGeometries("Islands",0,iGeometryNumber,Line6,PartMachined,0)
                |
                |          'Adding Line7 to Island number 3
                |          Call CurrentPMA.SetGeometries("Islands",0,iGeometryNumber,Line7,PartMachined,0)

        :param str i_geometry_type:
        :param int i_mode:
        :param int i_geometry_number:
        :param AnyObject i_reference:
        :param AnyObject i_product:
        :param int i_position:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.SetGeometries(
            i_geometry_type,
            i_mode,
            i_geometry_number,
            i_reference.com_object,
            i_product.com_object,
            i_position
        )

    def set_geometry(self, i_geometry_type: str, i_reference: AnyObject, i_product: AnyObject, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGeometry(CATBSTR iGeometryType,
                | AnyObject iReference,
                | AnyObject iProduct,
                | short iPosition)
                | 
                |     Sets a geometry of a specified type to a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             RelimitingPlane
                |                 to set the top plane 
                |             Parts
                |                 to set the bottom 
                |             Checks
                |                 to set a check element 
                | 
                |         iReference
                |             The geometry to be set. 
                |         iProduct
                |             The product containing the geometry to be set. 
                |         iPosition
                |             0 
                | 
                | 
                |         Example: The following example sets the top plane Plane2 to the
                |         manufacturing prismatic machining area CurrentPMA
                | 
                |          Call CurrentPMA.SetGeometry("RelimitingPlane",Plane2,PartMachined,0)

        :param str i_geometry_type:
        :param AnyObject i_reference:
        :param AnyObject i_product:
        :param int i_position:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.SetGeometry(
            i_geometry_type,
            i_reference.com_object,
            i_product.com_object,
            i_position
        )

    def set_open_contour_side(self, i_contour_number: int, i_point: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOpenContourSide(long iContourNumber,
                | AnyObject iPoint)
                | 
                |     Sets the side of one open contour of a Manufacturing Prismatic Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iContourNumber
                |             The geometry index inside the collection.
                | 
                |                 Must be between 1 and ContoursCount (see Properties).
                |                 
                | 
                |         iPoint
                |             A point near one of both limits of the contour.
                | 
                |                 From this limit to the other one, the side of the contour is on
                |                 the left. 
                |
                |         Example: The following example sets the side of the open contour number
                |         iContourNumber of the manufacturing prismatic machining area
                |         CurrentPMA
                | 
                |          Dim iContourNumber As Long
                |          iContourNumber = 3
                | 
                |          Dim Point1 As CATIABase
                |          ...
                |          Set Point1 = hybridShapes1.Item("Point.1")
                |          ...
                | 
                |          Call
                |          CurrentPMA.SetOpenContourSide(iContourNumber,Point1)

        :param int i_contour_number:
        :param AnyObject i_point:
        :rtype: None
        """
        return self.manufacturing_prismatic_machining_area.SetOpenContourSide(i_contour_number, i_point.com_object)

    def __repr__(self):
        return f'ManufacturingPrismaticMachiningArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_arc_commands.amp_tag import AMPTag
from pycatia.system_interfaces.any_object import AnyObject


class AMPPath(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AMPPath
                | 
                | This interface provides the methods to handle the feature AMPPath which is a
                | list of AMPTags.
                | 
                | USAGE :
                | This interface can be used only during AMP primitive file execution and not in
                | a stand alone VB script file. In the AMP primitive file, use the AMP "Execute"
                | keyword to execute a VB script file. For example:
                | 
                | Execute FREE path_name_of_the_VB_script_file
                | ( Example tutorial file:
                | /intel_a/startup/ARW/PRIMITIVES/AMPPath_AMPTag_Interfaces_Usage
                | )
                | 
                | The entry point in the VB script file is the CATMain method which takes a
                | single argument of type "AMPPath".
                | ( For more details, please refer to the following sample VB script file:
                | /intel_a/startup/ARW/PRIMITIVES/AMPPath_AMPTag_Interfaces_Usage.CATScript
                | )
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.amp_path = com_object

    def create_tag(self, i_location: tuple, o_tag: AMPTag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTag(CATSafeArrayVariant iLocation,
                | AMPTag oTag)
                | 
                |     Function to create an AMPTag.
                | 
                |     Parameters:
                | 
                |         iLocation
                |             The location (with respect to world reference frame) at which the
                |             AMPTag has to be created. 
                |         oTag
                |             The newly created AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param tuple i_location:
        :param AMPTag o_tag:
        :rtype: None
        """
        return self.amp_path.CreateTag(i_location, o_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag'
        # # vba_code = """
        # # Public Function create_tag(amp_path)
        # #     Dim iLocation (2)
        # #     amp_path.CreateTag iLocation
        # #     create_tag = iLocation
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_tag_with_reference(self, i_ref_tag: AMPTag, i_location: tuple, o_tag: AMPTag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTagWithReference(AMPTag iRefTag,
                | CATSafeArrayVariant iLocation,
                | AMPTag oTag)
                | 
                |     Function to create an AMPTag with reference to an already existing
                |     AMPTag.
                | 
                |     Parameters:
                | 
                |         iRefTag
                |             The AMPTag which is taken as the reference. 
                |         iLocation
                |             The location (with respect to iRefTag as the reference frame) at
                |             which the AMPTag has to be created. 
                |         oTag
                |             The newly created AMPTag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param AMPTag i_ref_tag:
        :param tuple i_location:
        :param AMPTag o_tag:
        :rtype: None
        """
        return self.amp_path.CreateTagWithReference(i_ref_tag.com_object, i_location, o_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag_with_reference'
        # # vba_code = """
        # # Public Function create_tag_with_reference(amp_path)
        # #     Dim iRefTag (2)
        # #     amp_path.CreateTagWithReference iRefTag
        # #     create_tag_with_reference = iRefTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_all_tags(self, io_tag_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllTags(CATSafeArrayVariant ioTagList)
                | 
                |     Function to get the list of AMPTags by name.
                | 
                |     Parameters:
                | 
                |         ioTagList
                |             Underlying list of AMPTag names. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param tuple io_tag_list:
        :rtype: None
        """
        return self.amp_path.GetAllTags(io_tag_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_tags'
        # # vba_code = """
        # # Public Function get_all_tags(amp_path)
        # #     Dim ioTagList (2)
        # #     amp_path.GetAllTags ioTagList
        # #     get_all_tags = ioTagList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_num_tags(self, otag_list_size: int) -> AMPTag:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNumTags(short otagListSize)
                | 
                |     Function to get the number of AMPTags in the given
                |     AMPPath.
                |     Usage:
                |     'Array of AMPTags; No size specified as size is not known
                |     Dim objAMPTags() As AMPTag
                | 
                |     'Size of the array objAMPTags is determined
                |     Dim count As Integer
                |     iAMPPath.GetNumTags count
                | 
                |     'Set the size of array objAMPTags
                |     ReDim objAMPTags(count)
                | 
                |     Parameters:
                | 
                |         otagListSize
                |             Number of AMPTags. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param int otag_list_size:
        :rtype: AMPTag
        """
        return AMPTag(self.amp_path.GetNumTags(otag_list_size))

    def get_script_var_value(self, o_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetScriptVarValue(CATBSTR oValue)
                | 
                |     Function to get the value of system variable, "ScriptVar".
                |     Usage:
                |     Dim myScriptVar As String
                |     iAMPPath.GetScriptVarValue myScriptVar
                | 
                |     Parameters:
                | 
                |         oValue
                |             Value of the system variable, "ScriptVar". 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str o_value:
        :rtype: None
        """
        return self.amp_path.GetScriptVarValue(o_value)

    def get_target_device(self, o_device: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTargetDevice(AnyObject oDevice)
                | 
                |     Function to get the target device of the AMPPath.
                | 
                |     Parameters:
                | 
                |         oDevice
                |             The target device of the AMPPath. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param AnyObject o_device:
        :rtype: None
        """
        return self.amp_path.GetTargetDevice(o_device.com_object)

    def insert_at(self, i_index: int, i_tag: AMPTag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InsertAt(short iIndex,
                | AMPTag iTag)
                | 
                |     Function to insert an AMPTag at a given index of the
                |     AMPPath.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of AMPPath at which the AMPTag has to be inserted.
                |             
                |         iTag
                |             The AMPTag that has to be inserted. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int i_index:
        :param AMPTag i_tag:
        :rtype: None
        """
        return self.amp_path.InsertAt(i_index, i_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_at'
        # # vba_code = """
        # # Public Function insert_at(amp_path)
        # #     Dim iIndex (2)
        # #     amp_path.InsertAt iIndex
        # #     insert_at = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_from(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveFrom(short iIndex)
                | 
                |     Function to remove an AMPTag at a given index of the
                |     AMPPath.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of AMPPath at which the AMPTag has to be removed.
                |
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param int i_index:
        :rtype: None
        """
        return self.amp_path.RemoveFrom(i_index)

    def __repr__(self):
        return f'AMPPath(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ArrangementRectangle(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementRectangle
                | 
                | Use this object to access the properties and methods of an ArrangementRectangle
                | object.
                | Role: The ArrangementRectangle object is a geometric shape used for defining
                | Contours of Areas. The ArrangementRectangle is defined by width and length and
                | its Product position (which is the min-x, min-y corner of the
                | rectangle).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_rectangle = com_object

    @property
    def x_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property XLength() As double
                | 
                |     Returns or sets the XLength of the ArrangementRectangle.
                | 
                |     Example:
                |         This example retrieves the XLength for the objRectangle1
                |         object.
                | 
                |          Dim dblXLength  As Double
                |          dblXLength = objRectangle1.XLength

        :rtype: float
        """

        return self.arrangement_rectangle.XLength

    @x_length.setter
    def x_length(self, value: float):
        """
        :param float value:
        """

        self.arrangement_rectangle.XLength = value

    @property
    def y_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property YLength() As double
                | 
                |     Returns or sets the YLength of the ArrangementRectangle.
                | 
                |     Example:
                |         This example retrieves the YLength for the objRectangle1
                |         object.
                | 
                |          Dim dblYLength  As Double
                |          dblYLength = objRectangle1.YLength

        :rtype: float
        """

        return self.arrangement_rectangle.YLength

    @y_length.setter
    def y_length(self, value: float):
        """
        :param float value:
        """

        self.arrangement_rectangle.YLength = value

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the applicative data which type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                |         oApplicativeObj
                |             The matched applicative object.
                | 
                |             Example:
                |                 This example retrieves the desired applicative object from the
                |                 objRectangle1 object.
                | 
                |                  Dim objProd   As Product
                |                  objProd  = objRectangle1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_rectangle.GetTechnologicalObject(i_application_type)

    def __repr__(self):
        return f'ArrangementRectangle(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class AnalysisMeshLocalSpecification(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisMeshLocalSpecification
                | 
                | The interface to access a CATIAAnalysisMeshLocalSpecification.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_mesh_local_specification = com_object

    @property
    def type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CATBSTR (Read Only)
                | 
                |     Returns the type of the local specification.
                | 
                |     Returns:
                |         The string that represent the type of local specification.

        :rtype: str
        """

        return self.analysis_mesh_local_specification.Type

    def add_support_from_publication(self, i_name: str, i_product: Product, i_support: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(CATBSTR iName,
                | Product iProduct,
                | Publication iSupport)
                | 
                |     Defines the support of the local specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier of the attribute. 
                |         iProduct
                |             the CATIA Product that represent the object to linked.
                |             
                |         iPublication
                |             the CATIA Publication that represent the geometry.
                |             
                | 
                |     See also:
                |         Publication, Product

        :param str i_name:
        :param Product i_product:
        :param Publication i_support:
        :rtype: None
        """
        return self.analysis_mesh_local_specification.AddSupportFromPublication(
            i_name,
            i_product.com_object,
            i_support.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(analysis_mesh_local_specification)
        # #     Dim iName (2)
        # #     analysis_mesh_local_specification.AddSupportFromPublication iName
        # #     add_support_from_publication = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_name: str, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(CATBSTR iName,
                | Product iProduct,
                | Reference iSupport)
                | 
                |     Defines the support of the local specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier of the attribute. 
                |         iProduct
                |             the CATIA Product that represent the object to linked.
                |             
                |         iSupport
                |             the CATIA Reference that represent the geometry. 
                | 
                |     See also:
                |         Reference, Product

        :param str i_name:
        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.analysis_mesh_local_specification.AddSupportFromReference(
            i_name,
            i_product.com_object,
            i_support.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(analysis_mesh_local_specification)
        # #     Dim iName (2)
        # #     analysis_mesh_local_specification.AddSupportFromReference iName
        # #     add_support_from_reference = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_attribute(self, i_name: str, i_value: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAttribute(CATBSTR iName,
                | CATVariant iValue)
                | 
                |     Sets the value corresponding to the given local
                |     specification.
                | 
                |     Parameters:
                | 
                |         iName
                |             The identifier of the attribute. 
                |         iValue
                |             The value of the local specification.

        :param str i_name:
        :param cat_variant i_value:
        :rtype: None
        """
        return self.analysis_mesh_local_specification.SetAttribute(i_name, i_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_attribute'
        # # vba_code = """
        # # Public Function set_attribute(analysis_mesh_local_specification)
        # #     Dim iName (2)
        # #     analysis_mesh_local_specification.SetAttribute iName
        # #     set_attribute = iName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisMeshLocalSpecification(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeHealing(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeHealing
                | 
                | Represents the hybrid shape healing feature object.
                | Role: Allows to access to the body to process for a Healing feature. Use the
                | CATIAHybridShapeFactory to create HybridShapeFeature object.
                | 
                | See also:
                |     HybridShapeFactory.AddNewHealing
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_healing = com_object

    @property
    def canonic_free_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CanonicFreeMode(long iMode)
                | 
                |     Returns or sets the Canonic Free Mode of the healing.
                | 
                |     Parameters:
                | 
                |         oMode
                |             (For get_CanonicFreeMode) Long parameter for retrieving the
                |             CanonicFreeMode. 
                |         iMode
                |             (For set_CanonicFreeMode) Long parameter for settingthe
                |             CanonicFreeMode.
                | 
                |             Example:
                |                 This example sets and retrieves the CanonicFreeMode of the
                |                 healing of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  Dim HybShpHealMode As  Long
                |                  HybShpHealMode = ..set appropriate value
                |                  HybShpHealing.CanonicFreeMode = HybShpHealMode
                |                  HybShpHealCont = HybShpHealing.CanonicFreeMode

        :rtype: int
        """

        return self.hybrid_shape_healing.CononicFreeMode

    @canonic_free_mode.setter
    def canonic_free_mode(self, mode: int):
        """
        :param int mode:
        """

        self.hybrid_shape_healing.CanonicFreeMode = mode

    @property
    def continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Continuity(long iContinuity)
                | 
                |     Returns or sets the continuity type of the healing.
                | 
                |     Parameters:
                | 
                |         Continuity
                |             Parameter for the continuity. Legal values are 0 and
                |             1
                | 
                |             Example:
                |                 This example sets and retrieves the Continuity of the healing
                |                 of the HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealCont As  Long
                |                  HybShpHealCont = ..set appropriate value
                |                  HybShpHealing.Continuity = HybShpHealCont
                |                  HybShpHealCont = HybShpHealing.Continuity

        :rtype: False
        """

        return self.hybrid_shape_healing.Continuity

    @continuity.setter
    def continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_healing.Continuity = value

    @property
    def distance_objective(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DistanceObjective() As Length (Read Only)
                | 
                |     Returns the Distance Objective of the healing.
                | 
                |     Parameters:
                | 
                |         DistanceObjective
                |             Length parameter for retrieving the Distance
                |             Objective.
                | 
                |             Example:
                |                 This example retrieves the DistanceObjective of the healing of
                |                 the HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealDistObjective As Length
                |                  Set HybShpHealDistObjective = HybShpHealing.DistanceObjective

        :rtype: Length
        """

        return Length(self.hybrid_shape_healing.DistanceObjective)

    @property
    def merging_distance(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MergingDistance() As Length (Read Only)
                | 
                |     Returns the Merging Distance of the healing.
                | 
                |     Parameters:
                | 
                |         MergingDistance
                |             Length parameter for retrieving the Merging
                |             Distance.
                | 
                |             Example:
                |                 This example retrieves the MergingDistance of the healing of
                |                 the HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealMergeDist As Length
                |                  Set HybShpHealMergeDist = HybShpHealing.MergingDistance

        :rtype: Length
        """

        return Length(self.hybrid_shape_healing.MergingDistance)

    @property
    def no_of_bodies_to_heal(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NoOfBodiesToHeal() As long (Read Only)
                | 
                |     Returns the number of bodies to heal of the healing.
                | 
                |     Parameters:
                | 
                |         NumberOfbodies
                |             Number of bodies to heal in the healing.
                | 
                |             Example:
                |                 This example retrieves the number of bodies to heal of the
                |                 HybShpHealing hybrid shape Healing.
                | 
                |                  Dim NoOfBodiesToHeal As  long
                |                  NoOfBodiesToHeal = HybShpHealing.NoOfBodiesToHeal

        :rtype: int
        """

        return self.hybrid_shape_healing.NoOfBodiesToHeal

    @property
    def no_of_edges_to_keep_sharp(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NoOfEdgesToKeepSharp() As long (Read Only)
                | 
                |     Returns the number of edges to keep sharp of the healing.
                | 
                |     Parameters:
                | 
                |         NumberOfEdges
                |             Number of edges to keep sharp.
                | 
                |             Example:
                |                 This example retrieves the number of edges to keep sharp of the
                |                 HybShpHealing hybrid shape Healing.
                | 
                |                  Dim NoOfEdges As  long
                |                  NoOfEdges = HybShpHealing.NoOfEdgesToKeepSharp

        :rtype: int
        """

        return self.hybrid_shape_healing.NoOfEdgesToKeepSharp

    @property
    def no_of_elements_to_freeze(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property NoOfElementsToFreeze() As long (Read Only)
                | 
                |     Returns the number of elements to heal of the healing.
                | 
                |     Parameters:
                | 
                |         NumberOfElements
                |             Number of elements to freeze in the healing.
                | 
                |             Example:
                |                 This example retrieves the number of elements to freeze of the
                |                 HybShpHealing hybrid shape Healing.
                | 
                |                  Dim NoOfElementsToFreeze As  long
                |                  NoOfElementsToFreeze = HybShpHealing.NoOfElementsToFreeze

        :rtype: int
        """

        return self.hybrid_shape_healing.NoOfElementsToFreeze

    @property
    def sharpness_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SharpnessAngle() As Angle (Read Only)
                | 
                |     Returns the Sharpness Angle of the healing.
                | 
                |     Parameters:
                | 
                |         SharpnessAngle
                |             Angle parameter for retrieving the Sharpness
                |             Angle.
                | 
                |             Example:
                |                 This example retrieves the Sharpness Angle of the healing of
                |                 the HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealSharpnessAngle As Angle
                |                  Set HybShpHealSharpnessAngle = HybShpHealing.SharpnessAngle

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_healing.SharpnessAngle)

    @property
    def tangency_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TangencyAngle() As Angle (Read Only)
                | 
                |     Returns the Tangency Angle of the healing.
                | 
                |     Parameters:
                | 
                |         TangencyAngle
                |             Angle parameter for retrieving the TangencyAngle.
                | 
                |             Example:
                |                 This example retrieves the TangencyAngle of the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealTangencyAngle As Angle
                |                  Set HybShpHealTangencyAngle = HybShpHealing.TangencyAngle

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_healing.TangencyAngle)

    @property
    def tangency_objective(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TangencyObjective() As Length (Read Only)
                | 
                |     Returns the Tangency Objective of the healing.
                | 
                |     Parameters:
                | 
                |         TangencyObjective
                |             Length parameter for retrieving the Tangency
                |             Objective.
                | 
                |             Example:
                |                 This example retrieves the TangencyObjective of the healing of
                |                 the HybShpHealing hybrid shape healing.
                | 
                |                  Dim HybShpHealTangencyObjective As Length
                |                  Set HybShpHealTangencyObjective = HybShpHealing.TangencyObjective

        :rtype: Length
        """

        return Length(self.hybrid_shape_healing.TangencyObjective)

    def add_body_to_heal(self, i_body: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddBodyToHeal(Reference iBody)
                | 
                |     Adds the body to be healed to the list.
                | 
                |     Parameters:
                | 
                |         Body
                |             Reference to the body to be added to the list.
                | 
                |             Example:
                |                 This example adds the body to the list. of the HybShpHealing
                |                 hybrid shape healing.
                | 
                |                  HybShpHealing.AddBodyToHeal refBody

        :param Reference i_body:
        :rtype: None
        """
        return self.hybrid_shape_healing.AddBodyToHeal(i_body.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_body_to_heal'
        # # vba_code = """
        # # Public Function add_body_to_heal(hybrid_shape_healing)
        # #     Dim iBody (2)
        # #     hybrid_shape_healing.AddBodyToHeal iBody
        # #     add_body_to_heal = iBody
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_edge_to_keep_sharp(self, i_edge: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddEdgeToKeepSharp(Reference iEdge)
                | 
                |     Adds the edge to be kept sharp while healing, to the list.
                | 
                |     Parameters:
                | 
                |         Edge
                |             Reference to the Edge to be kept sharp
                | 
                |             Example:
                |                 This example adds the Edge to the list of Edges to be kept
                |                 sharp. of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  HybShpHealing.AddEdgeToKeepSharp refEdge

        :param Reference i_edge:
        :rtype: None
        """
        return self.hybrid_shape_healing.AddEdgeToKeepSharp(i_edge.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_edge_to_keep_sharp'
        # # vba_code = """
        # # Public Function add_edge_to_keep_sharp(hybrid_shape_healing)
        # #     Dim iEdge (2)
        # #     hybrid_shape_healing.AddEdgeToKeepSharp iEdge
        # #     add_edge_to_keep_sharp = iEdge
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_elements_to_freeze(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementsToFreeze(Reference iElement)
                | 
                |     Adds the body to be freezed while healing, to the list.
                | 
                |     Parameters:
                | 
                |         Element
                |             Reference to the element to be freezed.
                | 
                |             Example:
                |                 This example adds the body to the list of bodies to be freezed.
                |                 of the HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.AddElementsToFreeze refElement

        :param Reference i_element:
        :rtype: None
        """
        return self.hybrid_shape_healing.AddElementsToFreeze(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_elements_to_freeze'
        # # vba_code = """
        # # Public Function add_elements_to_freeze(hybrid_shape_healing)
        # #     Dim iElement (2)
        # #     hybrid_shape_healing.AddElementsToFreeze iElement
        # #     add_elements_to_freeze = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_body_to_heal(self, i_position: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetBodyToHeal(long iPosition) As Reference
                | 
                |     Returns the body to be healed from the list at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         Position
                |             Position at which the body is to be obtained 
                |         Body
                |             Reference to the body obtained at specified
                |             position.
                | 
                |             Example:
                |                 This example gets the body from the list by specifying the
                |                 position. of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  set refBody = HybShpHealing.GetBodyToHeal  1

        :param int i_position:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_healing.GetBodyToHeal(i_position))

    def get_edge_to_keep_sharp(self, i_position: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetEdgeToKeepSharp(long iPosition) As Reference
                | 
                |     Returns the edge to be kept sharp from the list at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         Position
                |             Position at which the element is to be obtained 
                |         Edge
                |             Reference to the element obtained at specified
                |             position.
                | 
                |             Example:
                |                 This example gets the Edge from the list of Edges to be kept
                |                 sharp by specifying the position of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  set refEdge = HybShpHealing.GetEdgeToKeepSharp  1

        :param int i_position:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_healing.GetEdgeToKeepSharp(i_position))

    def get_element_to_freeze(self, i_position: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetElementToFreeze(long iPosition) As Reference
                | 
                |     Returns the element to be freezed from the list at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         Position
                |             Position at which the element is to be obtained 
                |         Element
                |             Reference to the element obtained at specified
                |             position.
                | 
                |             Example:
                |                 This example gets the element from the list of bodies to be
                |                 freezed by specifying the position of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  set refElement = HybShpHealing.GetElementToFreeze  1

        :param int i_position:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_healing.GetElementToFreeze(i_position))

    def remove_body_to_heal(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveBodyToHeal(long iPosition)
                | 
                |     Removes the body to be healed from the list at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position at which the body is to be removed
                | 
                |             Example:
                |                 This example removes the body from the list at specifying the
                |                 position. of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  HybShpHealing.RemoveBodyToHeal  1

        :param int i_position:
        :rtype: None
        """
        return self.hybrid_shape_healing.RemoveBodyToHeal(i_position)

    def remove_edge_to_keep_sharp(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveEdgeToKeepSharp(long iPosition)
                | 
                |     Removes the edge from the list of edges to be kept sharp at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position at which the edge is to be removed
                | 
                |             Example:
                |                 This example removes the edge from the list at specified
                |                 position. of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  HybShpHealing.RemoveEdgeToKeepSharp  1

        :param int i_position:
        :rtype: None
        """
        return self.hybrid_shape_healing.RemoveEdgeToKeepSharp(i_position)

    def remove_element_to_freeze(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToFreeze(long iPosition)
                | 
                |     Removes the element from the list of elements to be freezed at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         Position
                |             Position at which the element is to be removed
                | 
                |             Example:
                |                 This example removes the element from the list at specifying
                |                 the position. of the HybShpHealing hybrid shape
                |                 healing.
                | 
                |                  HybShpHealing.RemoveElementToFreeze  1

        :param int i_position:
        :rtype: None
        """
        return self.hybrid_shape_healing.RemoveElementToFreeze(i_position)

    def replace_to_heal_element(self, i_index: int, i_new_heal: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceToHealElement(long iIndex,
                | Reference iNewHeal)
                | 
                |     Replaces an element to heal.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The position of the element to replace. 
                |         iNewHeal
                |             The new element.

        :param int i_index:
        :param Reference i_new_heal:
        :rtype: None
        """
        return self.hybrid_shape_healing.ReplaceToHealElement(i_index, i_new_heal.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_to_heal_element'
        # # vba_code = """
        # # Public Function replace_to_heal_element(hybrid_shape_healing)
        # #     Dim iIndex (2)
        # #     hybrid_shape_healing.ReplaceToHealElement iIndex
        # #     replace_to_heal_element = iIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_distance_objective(self, i_distance_objective: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDistanceObjective(double iDistanceObjective)
                | 
                |     Sets the distance objective for healing entity.
                | 
                |     Parameters:
                | 
                |         DistanceObjective
                |             Parameter containg the value of the distance objective to be
                |             set.
                | 
                |             Example:
                |                 This example sets the distance objective for the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.SetDistanceObjective 2.5

        :param float i_distance_objective:
        :rtype: None
        """
        return self.hybrid_shape_healing.SetDistanceObjective(i_distance_objective)

    def set_merging_distance(self, i_merging_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMergingDistance(double iMergingDistance)
                | 
                |     Sets the Merging distance for healing entity.
                | 
                |     Parameters:
                | 
                |         MergingDistance
                |             Parameter containg the value of the merging distance to be
                |             set.
                | 
                |             Example:
                |                 This example sets the merging distance for the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.SetMergingDistance 2.5

        :param float i_merging_distance:
        :rtype: None
        """
        return self.hybrid_shape_healing.SetMergingDistance(i_merging_distance)

    def set_sharpness_angle(self, i_sharpness_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSharpnessAngle(double iSharpnessAngle)
                | 
                |     Sets the Sharpness Angle for healing entity.
                | 
                |     Parameters:
                | 
                |         SharpnessAngle
                |             Parameter containg the value of the Sharpness Angle to be
                |             set.
                | 
                |             Example:
                |                 This example sets the Sharpness Angle for the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.SetSharpnessAngle 2.5

        :param float i_sharpness_angle:
        :rtype: None
        """
        return self.hybrid_shape_healing.SetSharpnessAngle(i_sharpness_angle)

    def set_tangency_angle(self, i_tangency_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTangencyAngle(double iTangencyAngle)
                | 
                |     Sets the distance objective for healing entity.
                | 
                |     Parameters:
                | 
                |         TangencyAngle
                |             Parameter containg the value of the Tangency Angle to be
                |             set.
                | 
                |             Example:
                |                 This example sets the Tangency Angle for the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.SetTangencyAngle 2.5

        :param float i_tangency_angle:
        :rtype: None
        """
        return self.hybrid_shape_healing.SetTangencyAngle(i_tangency_angle)

    def set_tangency_objective(self, i_tangency_objective: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTangencyObjective(double iTangencyObjective)
                | 
                |     Sets the tangency objective for healing entity.
                | 
                |     Parameters:
                | 
                |         TangencyObjective
                |             Parameter containg the value of the Tangency Objective to be
                |             set.
                | 
                |             Example:
                |                 This example sets the Tangency Objective for the healing of the
                |                 HybShpHealing hybrid shape healing.
                | 
                |                  HybShpHealing.SetTangencyObjective 2.5

        :param float i_tangency_objective:
        :rtype: None
        """
        return self.hybrid_shape_healing.SetTangencyObjective(i_tangency_objective)

    def __repr__(self):
        return f'HybridShapeHealing(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_interaction import ABQInteraction
from pycatia.abq_automation_interfaces.abq_property import ABQProperty
from pycatia.analysis_interfaces.analysis_entity import AnalysisEntity
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.constraint import Constraint
from pycatia.product_structure_interfaces.product import Product


class ABQSurfaceToSurfaceContact(ABQInteraction):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQInteraction
                |                         ABQSurfaceToSurfaceContact
                | 
                | Represents an Abaqus contact pair (ABQSurfaceToSurfaceContact)
                | object.
                | Role: Access an Abaqus contact pair object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_surface_to_surface_contact = com_object

    @property
    def adjust_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AdjustMethod() As AdjustMethod_Type
                | 
                |     Sets or returns the method type in a contact pair.
                | 
                |     Returns:
                |         The method type.
                | 
                |         Legal values:
                | 
                |         OVERCLOSED
                |         TOLERANCE

        :return: enum adjust_method_type
        :rtype: int
        """

        return self.abq_surface_to_surface_contact.AdjustMethod

    @adjust_method.setter
    def adjust_method(self, value: int):
        """
        :param int value: enum adjust_method_type
        """

        self.abq_surface_to_surface_contact.AdjustMethod = value

    @property
    def adjust_tolerance_val(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AdjustToleranceVal() As double
                | 
                |     Sets or returns the tolerance value of the contact pair.
                | 
                |     Returns:
                |         The tolerance value of the contact pair.

        :rtype: float
        """

        return self.abq_surface_to_surface_contact.AdjustToleranceVal

    @adjust_tolerance_val.setter
    def adjust_tolerance_val(self, value: float):
        """
        :param float value:
        """

        self.abq_surface_to_surface_contact.AdjustToleranceVal = value

    @property
    def connection_property(self) -> AnalysisEntity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectionProperty() As AnalysisEntity
                | 
                |     Sets or returns the connection property in a contact pair.
                | 
                |     Returns:
                |         The connection property.

        :rtype: AnalysisEntity
        """

        return AnalysisEntity(self.abq_surface_to_surface_contact.ConnectionProperty)

    @connection_property.setter
    def connection_property(self, value: AnalysisEntity):
        """
        :param AnalysisEntity value:
        """

        self.abq_surface_to_surface_contact.ConnectionProperty = value

    @property
    def formulation_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FormulationOption() As FormulationOption_Type
                | 
                |     Sets or returns the formulation option in a contact pair.
                | 
                |     Returns:
                |         Formulation option type.
                | 
                |         Legal values:
                | 
                |         SURFACETOSURFACE
                |         NODETOSURFACE

        :return: enum formulation_option_type
        :rtype: int
        """

        return self.abq_surface_to_surface_contact.FormulationOption

    @formulation_option.setter
    def formulation_option(self, value: int):
        """
        :param int value: enum formulation_option_type
        """

        self.abq_surface_to_surface_contact.FormulationOption = value

    @property
    def interaction_property(self) -> ABQProperty:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InteractionProperty() As ABQProperty
                | 
                |     Sets or returns the interaction property in a contact
                |     pair.
                | 
                |     Returns:
                |         The specified ABQMechConnBehavior.

        :rtype: ABQProperty
        """

        return ABQProperty(self.abq_surface_to_surface_contact.InteractionProperty)

    @interaction_property.setter
    def interaction_property(self, value: ABQProperty):
        """
        :param ABQProperty value:
        """

        self.abq_surface_to_surface_contact.InteractionProperty = value

    @property
    def interference_fit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InterferenceFit() As double
                | 
                |     Assigns / gets interference fit of a contact pair. This can be assigned to
                |     contact pairs created in structual case except initialization
                |     step.
                | 
                |     Returns:
                |         The interference magnitude for gradual interference with uniform
                |         overclosure.
                |         returns 0 if no interference fit is defined. Usage: Dim abqSurfCont As ABQSurfaceToSurfaceContact Dim clearance As double Set clearance = 2.5 abqSurfCont.InterferenceFit = clearance

        :rtype: float
        """

        return self.abq_surface_to_surface_contact.InterferenceFit

    @interference_fit.setter
    def interference_fit(self, value: float):
        """
        :param float value:
        """

        self.abq_surface_to_surface_contact.InterferenceFit = value

    @property
    def interference_fit_amplitude(self) -> ABQProperty:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InterferenceFitAmplitude() As ABQProperty
                | 
                |     Assigns / gets interference fit amplitude of a contact
                |     pair.
                | 
                |     Returns:
                |         The interference fit amplitude for gradual interference with uniform
                |         overclosure.
                |         returns NULL if no interference fit is defined.
                |         returns E_FAIL if unable to find amplitude object. Usage: Dim abqSurfCont As ABQSurfaceToSurfaceContact Dim clearance As double Set clearance = 2.5 abqSurfCont.InterferenceFit = clearance Dim Amp As ABQProperty ....(Get the amplitude property) abqSurfCont.InterferenceFitAmplitude = Amp;

        :rtype: ABQProperty
        """

        return ABQProperty(self.abq_surface_to_surface_contact.InterferenceFitAmplitude)

    @interference_fit_amplitude.setter
    def interference_fit_amplitude(self, value: ABQProperty):
        """
        :param ABQProperty value:
        """

        self.abq_surface_to_surface_contact.InterferenceFitAmplitude = value

    @property
    def sliding(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Sliding() As Sliding_Type
                | 
                |     Sets or returns the sliding type in a contact pair.
                | 
                |     Returns:
                |         The sliding type.
                | 
                |         Legal values:
                | 
                |         FINITE
                |         SMALL

        :return: enum sliding_type
        :rtype: int
        """

        return self.abq_surface_to_surface_contact.Sliding

    @sliding.setter
    def sliding(self, value: int):
        """
        :param int value: enum sliding_type
        """

        self.abq_surface_to_surface_contact.Sliding = value

    @property
    def swap_master_slave(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SwapMasterSlave() As boolean
                | 
                |     Returns the activation status if the master surface is swapped as slave
                |     surface.
                | 
                |     Returns:
                |         A boolean specifying whether the master surface surface is swapped as
                |         slave.

        :rtype: bool
        """

        return self.abq_surface_to_surface_contact.SwapMasterSlave

    @swap_master_slave.setter
    def swap_master_slave(self, value: bool):
        """
        :param bool value:
        """

        self.abq_surface_to_surface_contact.SwapMasterSlave = value

    @property
    def use_automatic_geometry_smoothing(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseAutomaticGeometrySmoothing() As boolean
                | 
                |     Returns a boolean indicating whether automatic geometry smoothing is used
                |     for the contact pair
                | 
                |     Returns:
                |         boolean specifying whether automatic geometry smoothing is
                |         active.
                | 
                |         Legal values:
                | 
                |         TRUE
                |         FALSE

        :rtype: bool
        """

        return self.abq_surface_to_surface_contact.UseAutomaticGeometrySmoothing

    @use_automatic_geometry_smoothing.setter
    def use_automatic_geometry_smoothing(self, value: bool):
        """
        :param bool value:
        """

        self.abq_surface_to_surface_contact.UseAutomaticGeometrySmoothing = value

    @property
    def use_interference_fit_amplitude(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseInterferenceFitAmplitude() As boolean (Read
                | Only)
                | 
                |     Returns a boolean indicating whether amplitude is used in the interference
                |     fit for a contact pair
                | 
                |     Returns:
                |         boolean specifying whether user defined amplitude is active.

        :rtype: bool
        """

        return self.abq_surface_to_surface_contact.UseInterferenceFitAmplitude

    @property
    def use_master_negative_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseMasterNegativeSide() As boolean
                | 
                |     Returns the activation status if the master surface is specified as the
                |     negative side.
                | 
                |     Returns:
                |         A boolean specifying whether the master surface is specified as the
                |         negative side.

        :rtype: bool
        """

        return self.abq_surface_to_surface_contact.UseMasterNegativeSide

    @use_master_negative_side.setter
    def use_master_negative_side(self, value: bool):
        """
        :param bool value:
        """

        self.abq_surface_to_surface_contact.UseMasterNegativeSide = value

    @property
    def use_slave_negative_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseSlaveNegativeSide() As boolean
                | 
                |     Returns the activation status if the slave surface is specified as the
                |     negative side.
                | 
                |     Returns:
                |         A boolean specifying whether the slave surface is specified as the
                |         negative side.

        :rtype: bool
        """

        return self.abq_surface_to_surface_contact.UseSlaveNegativeSide

    @use_slave_negative_side.setter
    def use_slave_negative_side(self, value: bool):
        """
        :param bool value:
        """

        self.abq_surface_to_surface_contact.UseSlaveNegativeSide = value

    def add_support_from_constraint(self, i_reference: Product, i_support: Constraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromConstraint(Product iReference,
                | Constraint iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the contact is
                |             applied.
                |         iSupport
                |             The CATIA Constraint specifying the region to which the contact is
                |             applied.
                | 
                |             Refer: CATIAReference, CATIAProduct

        :param Product i_reference:
        :param Constraint i_support:
        :rtype: None
        """
        return self.abq_surface_to_surface_contact.AddSupportFromConstraint(
            i_reference.com_object,
            i_support.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_constraint'
        # # vba_code = """
        # # Public Function add_support_from_constraint(abq_surface_to_surface_contact)
        # #     Dim iReference (2)
        # #     abq_surface_to_surface_contact.AddSupportFromConstraint iReference
        # #     add_support_from_constraint = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Creates a new support and adds it to the description of the Analysis
                |     Entity.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The CATIA Reference specifying the object to which the contact is
                |             applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the contact is
                |             applied.
                | 
                |             Refer: CATIAReference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_surface_to_surface_contact.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_surface_to_surface_contact)
        # #     Dim iReference (2)
        # #     abq_surface_to_surface_contact.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_interference_fit(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveInterferenceFit()
                | 
                |     Removes interference fit from a contact pair feature.

        :rtype: None
        """
        return self.abq_surface_to_surface_contact.RemoveInterferenceFit()

    def __repr__(self):
        return f'ABQSurfaceToSurfaceContact(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class SchCompGroupExt(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCompGroupExt
                | 
                | Manage the graphical representation of a temporary group of schematic
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_comp_group_ext = com_object

    def get_placement_axis(self, o_db6_place_matrix: SchListOfDoubles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPlacementAxis(SchListOfDoubles oDb6PlaceMatrix)
                | 
                |     Get the placement axis for the component group.
                | 
                |     Parameters:
                | 
                |         oDb6PlaceMatrix
                |             Placement matrix of the component group (an array of 6 doubles) See
                |             
                |         SchGRRComp.GetTransformation2D for explanation of this argument.
                |         
                |     Example:
                |
                |          Dim objThisIntf As SchCompGroupExt
                |          Dim objArg1 As SchListOfDoubles
                |           ...
                |          objThisIntf.GetPlacementAxisobjArg1

        :param SchListOfDoubles o_db6_place_matrix:
        :rtype: None
        """
        return self.sch_comp_group_ext.GetPlacementAxis(o_db6_place_matrix.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_placement_axis'
        # # vba_code = """
        # # Public Function get_placement_axis(sch_comp_group_ext)
        # #     Dim oDb6PlaceMatrix (2)
        # #     sch_comp_group_ext.GetPlacementAxis oDb6PlaceMatrix
        # #     get_placement_axis = oDb6PlaceMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_placement_axis(self, o_db6_place_matrix: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlacementAxis(CATSafeArrayVariant oDb6PlaceMatrix)
                | 
                |     Set the placement axis for the component group.
                | 
                |     Parameters:
                | 
                |         iDb6PlaceMatrix
                |             Placement matrix of the component group (an array of 6 doubles) See
                |             
                | 
                |         SchGRRComp.GetTransformation2D for explanation of this argument.
                |         
                |     Example:
                |
                |          Dim objThisIntf As SchCompGroupExt
                |          Dim dbVar1(x) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetPlacementAxisdbVar1

        :param tuple o_db6_place_matrix:
        :rtype: tuple
        """
        return self.sch_comp_group_ext.SetPlacementAxis(o_db6_place_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_placement_axis'
        # # vba_code = """
        # # Public Function set_placement_axis(sch_comp_group_ext)
        # #     Dim oDb6PlaceMatrix (2)
        # #     sch_comp_group_ext.SetPlacementAxis oDb6PlaceMatrix
        # #     set_placement_axis = oDb6PlaceMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCompGroupExt(name="{self.name}")'
